@@ -29,4 +29,4 @@ link_files = {
 # Custom sidebar templates, maps document names to template names.
 html_theme = 'alabaster'
 templates_path = ['_templates']
-html_sidebars = {'index': 'tidelift-sidebar.html'}
+html_sidebars = {'index': ['tidelift-sidebar.html']}
