@@ -196,15 +196,15 @@ def _load_plugins():
 
     `initialize_func` is optional, but will be invoked if callable.
     """
-    entry_points = metadata.entry_points()['keyring.backends']
+    entry_points = metadata.entry_points().get('keyring.backends', [])
     for ep in entry_points:
         try:
-            log.info('Loading %s', ep.name)
+            log.debug('Loading %s', ep.name)
             init_func = ep.load()
             if callable(init_func):
                 init_func()
         except Exception:
-            log.exception("Error initializing plugin %s." % ep)
+            log.exception("Error initializing plugin {ep}.".format(**locals()))
 
 
 @util.once
