@@ -11,6 +11,6 @@ def is_osx_keychain_supported():
 
 
 @pytest.mark.skipif(not is_osx_keychain_supported(), reason="Needs macOS")
-class OSXKeychainTestCase(BackendBasicTests):
+class TestOSXKeychain(BackendBasicTests):
     def init_keyring(self):
         return OS_X.Keyring()
