@@ -9,7 +9,7 @@ from keyring.testing.backend import BackendBasicTests
 @pytest.mark.skipif(
     not keyring.backends.Windows.WinVaultKeyring.viable, reason="Needs Windows"
 )
-class WinVaultKeyringTestCase(BackendBasicTests):
+class TestWinVaultKeyring(BackendBasicTests):
     def tearDown(self):
         # clean up any credentials created
         for cred in self.credentials_created:
@@ -21,6 +21,9 @@ class WinVaultKeyringTestCase(BackendBasicTests):
     def init_keyring(self):
         return keyring.backends.Windows.WinVaultKeyring()
 
+    def test_long_password_nice_error(self):
+        self.keyring.set_password('system', 'user', 'x' * 512 * 2)
+
 
 @pytest.mark.skipif('sys.platform != "win32"')
 def test_winvault_always_viable():
